@@ -74,7 +74,7 @@ int main(int argc, char** argv)
     std::string config_dir;
     bool show_version = false;
     bool start_paused = false;
-    bool is_iconified = false;
+    bool start_iconified = false;
 
     /* parse the command line */
     auto const config_dir_option = create_option_entry("config-dir", 'g', _("Where to look for configuration files"));
@@ -85,7 +85,7 @@ int main(int argc, char** argv)
     Glib::OptionGroup main_group({}, {});
     main_group.add_entry_filename(config_dir_option, config_dir);
     main_group.add_entry(paused_option, start_paused);
-    main_group.add_entry(minimized_option, is_iconified);
+    main_group.add_entry(minimized_option, start_iconified);
     main_group.add_entry(version_option, show_version);
 
     Glib::OptionContext option_context(_("[torrent files or urls]"));
@@ -134,5 +134,5 @@ int main(int argc, char** argv)
     gtr_notify_init();
 
     /* init the application for the specified config dir */
-    return Application(config_dir, start_paused, is_iconified).run(argc, argv);
+    return Application(config_dir, start_paused, start_iconified).run(argc, argv);
 }
