@@ -52,7 +52,11 @@ public:
     void reset(tr_block_info const& block_info, uint64_t const* file_sizes, size_t n_files);
     void reset(tr_torrent_metainfo const& tm);
 
-    [[nodiscard]] piece_span_t pieceSpan(tr_file_index_t file) const;
+    [[nodiscard]] TR_CONSTEXPR20 piece_span_t pieceSpan(tr_file_index_t file) const noexcept
+    {
+        return file_pieces_[file];
+    }
+
     [[nodiscard]] file_span_t fileSpan(tr_piece_index_t piece) const;
 
     [[nodiscard]] file_offset_t fileOffset(uint64_t offset) const;
@@ -62,6 +66,11 @@ public:
         return std::size(file_pieces_);
     }
 
+    [[nodiscard]] TR_CONSTEXPR20 bool empty() const noexcept
+    {
+        return std::empty(file_pieces_);
+    }
+
     // TODO(ckerr) minor wart here, two identical span types
     [[nodiscard]] tr_byte_span_t byteSpan(tr_file_index_t file) const
     {
