@@ -171,6 +171,11 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
             file_subpath_.clear();
             file_length_ = 0;
         }
+        else if (pathStartsWith(InfoKey, FilesKey, ""sv, PathUtf8Key))
+        {
+            // torrent has a utf8 path, drop the other one due to probable non-utf8 encoding
+            file_subpath_.clear();
+        }
 
         return BasicHandler::StartArray(context);
     }
@@ -251,7 +256,8 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
             pathStartsWith(InfoKey, FileDurationKey) || //
             pathStartsWith(InfoKey, FileMediaKey) || //
             pathStartsWith(InfoKey, ProfilesKey) || //
-            pathStartsWith(LibtorrentResumeKey))
+            pathStartsWith(LibtorrentResumeKey) || //
+            pathStartsWith(NodesKey))
         {
             // unused by Transmission
         }
@@ -292,7 +298,7 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
         }
         else if (state_ == State::Files)
         {
-            if (curdepth > 1 && key(curdepth - 1) == PathKey)
+            if (curdepth > 1 && (key(curdepth - 1) == PathKey || key(curdepth - 1) == PathUtf8Key))
             {
                 if (!std::empty(file_subpath_))
                 {
@@ -312,8 +318,7 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
                 pathIs(InfoKey, FilesKey, ""sv, Md5Key) || //
                 pathIs(InfoKey, FilesKey, ""sv, Md5sumKey) || //
                 pathIs(InfoKey, FilesKey, ""sv, MtimeKey) || // (why a string?)
-                pathIs(InfoKey, FilesKey, ""sv, Sha1Key) || //
-                pathStartsWith(InfoKey, FilesKey, ""sv, PathUtf8Key))
+                pathIs(InfoKey, FilesKey, ""sv, Sha1Key))
             {
                 // unused by Transmission
             }
@@ -330,7 +335,10 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
         {
             tm_.creator_ = tr_strv_replace_invalid(value);
         }
-        else if (pathIs(SourceKey) || pathIs(InfoKey, SourceKey) || pathIs(PublisherKey) || pathIs(InfoKey, PublisherKey))
+        else if (
+            pathIs(SourceKey) || pathIs(InfoKey, SourceKey) || //
+            pathIs(PublisherKey) || pathIs(InfoKey, PublisherKey) || //
+            pathIs(PublisherUtf8Key) || pathIs(InfoKey, PublisherUtf8Key))
         {
             // “publisher” is rare, but used by BitComet and appears
             // to have the same use as the 'source' key
@@ -404,12 +412,14 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
             pathIs(InfoKey, EntropyKey) || //
             pathIs(InfoKey, Md5sumKey) || //
             pathIs(InfoKey, PublisherUrlKey) || //
+            pathIs(InfoKey, PublisherUrlUtf8Key) || //
             pathIs(InfoKey, Sha1Key) || //
             pathIs(InfoKey, UniqueKey) || //
             pathIs(InfoKey, XCrossSeedKey) || //
             pathIs(LocaleKey) || //
             pathIs(LogCallbackKey) || //
             pathIs(PublisherUrlKey) || //
+            pathIs(PublisherUrlUtf8Key) || //
             pathIs(TitleKey) || //
             pathStartsWith(AzureusPrivatePropertiesKey) || //
             pathStartsWith(AzureusPropertiesKey) || //
@@ -417,7 +427,8 @@ struct MetainfoHandler final : public transmission::benc::BasicHandler<MaxBencDe
             pathStartsWith(InfoKey, FileDurationKey) || //
             pathStartsWith(InfoKey, ProfilesKey) || //
             pathStartsWith(LibtorrentResumeKey) || //
-            pathStartsWith(MagnetInfoKey))
+            pathStartsWith(MagnetInfoKey) || //
+            pathStartsWith(NodesKey))
         {
             // unused by Transmission
         }
@@ -510,12 +521,6 @@ private:
 
     bool finish(Context const& context)
     {
-        // Support Transmission <= 3.0 magnets stored in torrent format.
-        if (tm_.has_magnet_info_hash_)
-        {
-            return true;
-        }
-
         // bittorrent 1.0 spec
         // http://bittorrent.org/beps/bep_0003.html
         //
@@ -529,26 +534,34 @@ private:
             tm_.files_.add(tm_.name_, length_);
         }
 
-        if (tm_.fileCount() == 0)
+        if (auto const has_metainfo = tm_.infoDictSize() != 0U; has_metainfo)
         {
-            if (!tr_error_is_set(context.error))
+            // do some sanity checks to make sure the torrent looks sane
+            if (tm_.fileCount() == 0)
             {
-                tr_error_set(context.error, EINVAL, "no files found");
+                if (!tr_error_is_set(context.error))
+                {
+                    tr_error_set(context.error, EINVAL, "no files found");
+                }
+                return false;
             }
-            return false;
+
+            if (piece_size_ == 0)
+            {
+                if (!tr_error_is_set(context.error))
+                {
+                    tr_error_set(context.error, EINVAL, fmt::format("invalid piece size: {}", piece_size_));
+                }
+                return false;
+            }
+
+            tm_.block_info_.initSizes(tm_.files_.totalSize(), piece_size_);
+            return true;
         }
 
-        if (piece_size_ == 0)
-        {
-            if (!tr_error_is_set(context.error))
-            {
-                tr_error_set(context.error, EINVAL, fmt::format("invalid piece size: {}", piece_size_));
-            }
-            return false;
-        }
-
-        tm_.block_info_.initSizes(tm_.files_.totalSize(), piece_size_);
-        return true;
+        // no metainfo; might be a Transmission 3.00-style magnet file
+        auto const ok = tm_.has_magnet_info_hash_;
+        return ok;
     }
 
     static constexpr std::string_view AcodecKey = "acodec"sv;
@@ -592,6 +605,7 @@ private:
     static constexpr std::string_view MtimeKey = "mtime"sv;
     static constexpr std::string_view NameKey = "name"sv;
     static constexpr std::string_view NameUtf8Key = "name.utf-8"sv;
+    static constexpr std::string_view NodesKey = "nodes"sv;
     static constexpr std::string_view PathKey = "path"sv;
     static constexpr std::string_view PathUtf8Key = "path.utf-8"sv;
     static constexpr std::string_view PieceLayersKey = "piece layers"sv;
@@ -601,7 +615,9 @@ private:
     static constexpr std::string_view PrivateKey = "private"sv;
     static constexpr std::string_view ProfilesKey = "profiles"sv;
     static constexpr std::string_view PublisherKey = "publisher"sv;
+    static constexpr std::string_view PublisherUtf8Key = "publisher.utf-8"sv;
     static constexpr std::string_view PublisherUrlKey = "publisher-url"sv;
+    static constexpr std::string_view PublisherUrlUtf8Key = "publisher-url.utf-8"sv;
     static constexpr std::string_view Sha1Key = "sha1"sv;
     static constexpr std::string_view SourceKey = "source"sv;
     static constexpr std::string_view TitleKey = "title"sv;
@@ -677,22 +693,20 @@ bool tr_torrent_metainfo::migrateFile(
     std::string_view suffix)
 {
     auto const old_filename = makeFilename(dirname, name, info_hash_string, BasenameFormat::NameAndPartialHash, suffix);
-    auto const old_filename_exists = tr_sys_path_exists(old_filename);
-    auto const new_filename = makeFilename(dirname, name, info_hash_string, BasenameFormat::Hash, suffix);
-    auto const new_filename_exists = tr_sys_path_exists(new_filename);
+    if (!tr_sys_path_exists(old_filename))
+    {
+        return false;
+    }
 
-    if (old_filename_exists && new_filename_exists)
+    auto const new_filename = makeFilename(dirname, name, info_hash_string, BasenameFormat::Hash, suffix);
+    if (tr_sys_path_exists(new_filename))
     {
         tr_sys_path_remove(old_filename);
         return false;
     }
 
-    if (new_filename_exists)
-    {
-        return false;
-    }
-
-    if (old_filename_exists && tr_sys_path_rename(old_filename, new_filename))
+    auto const renamed = tr_sys_path_rename(old_filename, new_filename);
+    if (!renamed)
     {
         tr_logAddError(
             fmt::format(
@@ -703,7 +717,7 @@ bool tr_torrent_metainfo::migrateFile(
         return true;
     }
 
-    return false; // neither file exists
+    return renamed;
 }
 
 void tr_torrent_metainfo::removeFile(
